"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
function streamToRx(stream) {
    return new rxjs_1.Observable(subscriber => {
        const endHandler = () => subscriber.complete();
        const errorHandler = (e) => subscriber.error(e);
        const dataHandler = (data) => subscriber.next(data);
        stream.addListener('end', endHandler);
        stream.addListener('error', errorHandler);
        stream.addListener('data', dataHandler);
        return () => {
            stream.removeListener('end', endHandler);
            stream.removeListener('error', errorHandler);
            stream.removeListener('data', dataHandler);
        };
    });
}
exports.streamToRx = streamToRx;
function streamToStringRx(stream, encoding = 'UTF-8') {
    return streamToRx(stream)
        .pipe(operators_1.map(buffer => buffer.toString(encoding)));
}
exports.streamToStringRx = streamToStringRx;
//# sourceMappingURL=streamToRx.js.map